# Copyright 2014 San Francisco Estuary Institute.

# This file is part of RipZET.
#
# RipZET is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# RipZET is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with RipZET.  If not, see http://www.gnu.org/licenses/.


import os
from common.sfei_projection import NAD_1983_California_Teale_Albers

# called on application startup to initialize data paths
def initializePaths(mainDir):
    global MAIN_DIR, DATA_DIR, LOG_FILE, RIPZET_GDB, PPT_RASTER, FLOOD_FREQ_TABLE, XL_PARSER_EXE, XL_TEMPLATE_FILE, \
        BLANK_MXD, ELEVATION_SYMBOLOGY_LYR, STREAM_SYMBOLOGY_LYR, TRANSECT_SYMBOLOGY_LYR, TRANSECT_LOCATION_SYMBOLOGY_LYR, \
        WATERSHED_SYMBOLOGY_LYR, Q2_SYMBOLOGY_LYR, Q10_SYMBOLOGY_LYR, Q50_SYMBOLOGY_LYR, REACH_SYMBOLOGY_LYR, ZONE_POINT_SYMBOLOGY_LYR, \
        STREAM_POLY_SYMBOLOGY_LYR, STREAM_PARALLEL_SYMBOLOGY_LYR, HILLSLOPE_ZONE_SYMBOLOGY_LYR, VEGETATION_ZONE_SYMBOLOGY_LYR, \
        Q2_POINT_SYMBOLOGY_LYR, Q10_POINT_SYMBOLOGY_LYR, Q50_POINT_SYMBOLOGY_LYR, THALWEG_POINT_SYMBOLOGY_LYR

    MAIN_DIR = mainDir
    DATA_DIR = os.path.join(mainDir, "data")
    LOG_FILE = os.path.join(MAIN_DIR, "ripzet_log.txt")
    # these data files are packaged with the tool
    RIPZET_GDB = os.path.join(DATA_DIR, "ripzet.gdb")
    PPT_RASTER = os.path.join(RIPZET_GDB, "PRISM_ppt_30yr_normal_800mM2_annual_CA_TealeAlbers")
    FLOOD_FREQ_TABLE = os.path.join(RIPZET_GDB, "FloodFrequency")
    XL_PARSER_EXE = os.path.join(MAIN_DIR, "HyConXLSParser.exe")
    XL_TEMPLATE_FILE = os.path.join(MAIN_DIR, "HyCon_Template.xlsm")
    BLANK_MXD = os.path.join(DATA_DIR, "blank.mxd")
    ELEVATION_SYMBOLOGY_LYR = os.path.join(DATA_DIR, "elevation_symbology.lyr")
    STREAM_SYMBOLOGY_LYR = os.path.join(DATA_DIR, "stream_symbology.lyr")
    TRANSECT_SYMBOLOGY_LYR = os.path.join(DATA_DIR, "transect_symbology.lyr")
    TRANSECT_LOCATION_SYMBOLOGY_LYR = os.path.join(DATA_DIR, "transect_location_symbology.lyr")
    WATERSHED_SYMBOLOGY_LYR = os.path.join(DATA_DIR, "watershed_symbology.lyr")
    Q2_SYMBOLOGY_LYR = os.path.join(DATA_DIR, "q2_symbology.lyr")
    Q10_SYMBOLOGY_LYR = os.path.join(DATA_DIR, "q10_symbology.lyr")
    Q50_SYMBOLOGY_LYR = os.path.join(DATA_DIR, "q50_symbology.lyr")
    Q2_POINT_SYMBOLOGY_LYR = os.path.join(DATA_DIR, "q2_point_symbology.lyr")
    Q10_POINT_SYMBOLOGY_LYR = os.path.join(DATA_DIR, "q10_point_symbology.lyr")
    Q50_POINT_SYMBOLOGY_LYR = os.path.join(DATA_DIR, "q50_point_symbology.lyr")
    THALWEG_POINT_SYMBOLOGY_LYR = os.path.join(DATA_DIR, "thalweg_point_symbology.lyr")
    REACH_SYMBOLOGY_LYR = os.path.join(DATA_DIR, "reach_symbology.lyr")
    ZONE_POINT_SYMBOLOGY_LYR = os.path.join(DATA_DIR, "zone_point_symbology.lyr")
    STREAM_PARALLEL_SYMBOLOGY_LYR = os.path.join(DATA_DIR, "stream_parallel_symbology.lyr")
    STREAM_POLY_SYMBOLOGY_LYR = os.path.join(DATA_DIR, "stream_poly_symbology.lyr")
    HILLSLOPE_ZONE_SYMBOLOGY_LYR = os.path.join(DATA_DIR, "hillslope_zone_symbology.lyr")
    VEGETATION_ZONE_SYMBOLOGY_LYR = os.path.join(DATA_DIR, "vegetation_zone_symbology.lyr")

CREATE_SUMMARY_FILE = False
CREATE_MESSAGES_FILE = True
CREATE_HIGH_RESOLUTION_REACH = True

TOOLBOX_NAME = "RipZET Tools"
PREP_MODULE_NAME = "Prep"
HILLSLOPE_MODULE_NAME = "Hillslope"
VEGETATION_MODULE_NAME = "Vegetation"
RIPARIAN_BUFFERS_MODULE_NAME = "Riparian Buffers"
HYCON_MODULE_NAME = "HyCon"

# the sr that imported features will be converted to
STANDARD_SR = NAD_1983_California_Teale_Albers

def transectDisplayName():
    return "cross-section"  #"transect"

def transectDataName():
    return "cross_section"  #"transect

TOOL_MODE_GENERATE_NEW_TRANSECTS = "Generate New {0}s".format(transectDisplayName().title())
TOOL_MODE_REGENERATE_TRANSECTS = "Regenerate {0}s".format(transectDisplayName().title())
TOOL_MODES = [TOOL_MODE_GENERATE_NEW_TRANSECTS,
              TOOL_MODE_REGENERATE_TRANSECTS]

TRANSECT_LOC_OPTION_KEEP_ALL_LOCS = "Preserve Locations"
TRANSECT_LOC_OPTION_REGENERATE_REACH = "Regenerate Reach"
TRANSECT_LOC_OPTIONS = [TRANSECT_LOC_OPTION_KEEP_ALL_LOCS,
                        TRANSECT_LOC_OPTION_REGENERATE_REACH]

HYCON_CREATE_ZONE_POLYS = False
HYCON_CREATE_ALL_Q_PTS = True

UPSTREAM = 0
SITE = 1
DOWNSTREAM = 2
TRANSECT_IDS = [UPSTREAM, SITE, DOWNSTREAM]
TRANSECT_TYPES = ["upstream", "site", "downstream"]
_UP = "_up"
_DN = "_dn"

SLOPE_SIGNIFICANT_DIGITS = 3

ARGS_SPACE_CHAR = "?"

# HYCON XL TEMPLATE COL/ROW CONSTANTS
XL_Q_VALUES_COL = "BN"
XL_Q_VALUES_START_ROW = 19
XL_Q2_DISCHARGE_ROW = XL_Q_VALUES_START_ROW + 0
XL_Q2_DEPTH_ROW = XL_Q_VALUES_START_ROW + 1
XL_Q2_STAGE_ROW = XL_Q_VALUES_START_ROW + 2
XL_Q10_DISCHARGE_ROW = XL_Q_VALUES_START_ROW + 3
XL_Q10_DEPTH_ROW = XL_Q_VALUES_START_ROW + 4
XL_Q10_STAGE_ROW = XL_Q_VALUES_START_ROW + 5
XL_Q50_DISCHARGE_ROW = XL_Q_VALUES_START_ROW + 6
XL_Q50_DEPTH_ROW = XL_Q_VALUES_START_ROW + 7
XL_Q50_STAGE_ROW = XL_Q_VALUES_START_ROW + 8

def gdbPrefix():
    return "ripzet_"

def tempGDBSuffix():
    return "_work"

def resultsGDBSuffix():
    return "_results"

def summarySuffix():
    return "_summary"

def messagesSuffix():
    return "_messages"

def mapSuffix():
    return "_map"

def strOrderField():
    return "strOrder"

def hyConStrIdField():
    return "hyConId"

def hyConDatasetName():
    return "hyConMod"

def transectIdField():
    return transectDataName() + "_id"

def transectTypeField():
    return "type"
